ProgressBar
======================================

.. currentmodule:: enaml.widgets.progress_bar

.. autoclass:: ProgressBar


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_progress_bar.QtProgressBar
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_progress_bar.QtProgressBar

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_progress_bar.WXProgressBar
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_progress_bar.WXProgressBar
